import unittest
import random
import string
from nemonet.engines.sequencer import Sequences
from nemonet.engines.graph import Graph

class SequenceTestCase(unittest.TestCase):
    def test_something(self):
        g = Graph()
        g.build('graph-screen-type')
        seq = Sequences(g)
        self.executeSequences(seq, g)

    def click_xpath( self, arg ):
        pass

    def fill_in_text(self, arg, str):
        pass

    def execute_script(self , arg):
        pass

    def click_element_in_list(self, arg, value):
        pass

    def executeSequences(self, seq, g):
        pa = seq.get()
        self.assertTrue( pa == [['A', 'C', 'E', 'G'], ['A', 'D', 'G'], ['A', 'C', 'E', 'H'], ['A', 'D', 'H'], ['A', 'C', 'E', 'F', 'I'], ['A', 'D', 'F', 'I'], ['B', 'G'], ['B', 'H'], ['B', 'F', 'I']])
        for l in pa:
            for el in l:
                a = g.getVertex(el).getAction()

                if a.getElementType() == 'CLICKABLE':
                    self.click_xpath(a.getXpathStr())
                elif a.getElementType() == 'TEXTABLE':
                    rStr = ''.join([random.choice(string.ascii_letters + string.digits) for n in range(32)])
                    self.fill_in_text(a.getXpathStr(), rStr)
                elif a.getElementType() == 'JSexec':
                    self.execute_script(a.getXpathStr())
                elif a.getElementType() == 'SELECTABLE':
                    self.click_element_in_list(a.getXpathStr(), 2)

if __name__ == '__main__':
    unittest.main()



import unittest
from nemonet.engines.cache_store import KeyValueStore

class StringReformatTestCase(unittest.TestCase):

    def setUp(self) -> None:
        self.cache = KeyValueStore()
        self.cache.add('cu_2','cx_2')
        self.cache.add('cu_3','cx_3')

    def tearDown(self) -> None:
        self.cache.close()

    def test_string_formatter_use_case_1(self):
        self.assertTrue(self.cache.replace_formated_key("https://jqueryui.com/#{cu_2}/#{cu_3}") == 'https://jqueryui.com/cx_2/cx_3')

    def test_string_formatter_use_case_2(self):
        self.assertTrue(self.cache.replace_formated_key("https://jqueryui.com/#{cu_3}/#{cu_2}") == 'https://jqueryui.com/cx_3/cx_2')

    def test_string_formatter_key_not_in_cache(self):
        with self.assertRaises(KeyError):
            self.cache.replace_formated_key("https://jqueryui.com/#{cu_4}/#{cu_5}")

    def test_string_formatter_only_one_valid_key(self):
        self.assertTrue(self.cache.replace_formated_key("https://jqueryui.com/#{cu_3}/#cu_2}") == 'https://jqueryui.com/cx_3/#cu_2}')


if __name__ == '__main__':
    unittest.main()



import h5py
import chardet
import re

class KeyValueStore(object):

    def __init__(self):
        self.a_cache = h5py.File("cache.hdf5", "a")

    def add(self , key , value):
        self.a_cache.attrs[ key ] = value

    def get_value_as_str(self, key ):
        return self.a_cache.attrs[ key ]

    def close(self):
        self.a_cache.close()

    def replace_formated_key(self, formatted_str):
        m_keys = re.findall(r'(#{.*?})', formatted_str)
        result_fromated_str = formatted_str
        for item in m_keys:
            item_start = 2
            item_end = len(item) - 1
            result_fromated_str = result_fromated_str.replace(item, self.get_value_as_str(item[item_start:item_end]))
        return result_fromated_str